import { makeFieldSchemaFromZod } from '@backstage/plugin-scaffolder';
import { z } from 'zod';

const selectFieldFromApiSchema = z.object({
  params: z.union([
    z.record(z.string(), z.string()),
    z.array(z.record(z.string(), z.string()))
  ]).optional(),
  path: z.string().describe(
    "The Path on the Backstage API and the parameters to fetch the data for the dropdown"
  ),
  arraySelector: z.union([z.string(), z.array(z.string())]).optional().describe(
    "This selects the array element from the API fetch response. It finds the array with the name kind"
  ),
  valueSelector: z.union([z.string(), z.array(z.string())]).optional().describe(
    "This selects the field in the array to use for the value of each select item. If its not specified it will use the value of the item directly."
  ),
  labelSelector: z.union([z.string(), z.array(z.string())]).optional().describe(
    "This selects the field in the array to use for the label of each select item"
  ),
  title: z.string().optional(),
  placeholder: z.string().optional().describe(
    "Renders the provided text as a placeholder value into the select box"
  ),
  description: z.string().optional()
});
const SelectFieldFromApiSchema = makeFieldSchemaFromZod(
  z.any(),
  selectFieldFromApiSchema
).schema;

export { SelectFieldFromApiSchema, selectFieldFromApiSchema };
//# sourceMappingURL=schema.esm.js.map
